@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import warnings
+
 from tencentcloud.common.abstract_model import AbstractModel
 
 
@@ -43,6 +45,13 @@ class CaptchaOperDataInterceptUnit(AbstractModel):
         self.AllStopCnt = params.get("AllStopCnt")
         self.PicStopCnt = params.get("PicStopCnt")
         self.StrategyStopCnt = params.get("StrategyStopCnt")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CaptchaOperDataLoadTimeUnit(AbstractModel):
@@ -68,6 +77,13 @@ class CaptchaOperDataLoadTimeUnit(AbstractModel):
         self.DateKey = params.get("DateKey")
         self.MarketLoadTime = params.get("MarketLoadTime")
         self.AppIdLoadTime = params.get("AppIdLoadTime")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CaptchaOperDataRes(AbstractModel):
@@ -121,6 +137,13 @@ class CaptchaOperDataRes(AbstractModel):
                 obj = CaptchaOperDataTryTimesDistributeUnit()
                 obj._deserialize(item)
                 self.OperDataTryTimesDistributeUnitArray.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CaptchaOperDataTryTimesDistributeUnit(AbstractModel):
@@ -142,6 +165,13 @@ class CaptchaOperDataTryTimesDistributeUnit(AbstractModel):
     def _deserialize(self, params):
         self.TryCount = params.get("TryCount")
         self.UserCount = params.get("UserCount")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CaptchaOperDataTryTimesUnit(AbstractModel):
@@ -167,6 +197,13 @@ class CaptchaOperDataTryTimesUnit(AbstractModel):
         self.DateKey = params.get("DateKey")
         self.CntPerPass = params.get("CntPerPass")
         self.MarketCntPerPass = params.get("MarketCntPerPass")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CaptchaQueryData(AbstractModel):
@@ -188,6 +225,13 @@ class CaptchaQueryData(AbstractModel):
     def _deserialize(self, params):
         self.Cnt = params.get("Cnt")
         self.Date = params.get("Date")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CaptchaTicketDataRes(AbstractModel):
@@ -228,6 +272,13 @@ class CaptchaTicketDataRes(AbstractModel):
                 obj = TicketInterceptUnit()
                 obj._deserialize(item)
                 self.TicketInterceptArray.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CaptchaUserAllAppId(AbstractModel):
@@ -257,6 +308,13 @@ class CaptchaUserAllAppId(AbstractModel):
         self.AppName = params.get("AppName")
         self.TcAppId = params.get("TcAppId")
         self.ChannelInfo = params.get("ChannelInfo")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeCaptchaAppIdInfoRequest(AbstractModel):
@@ -274,6 +332,13 @@ class DescribeCaptchaAppIdInfoRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.CaptchaAppId = params.get("CaptchaAppId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeCaptchaAppIdInfoResponse(AbstractModel):
@@ -382,6 +447,13 @@ class DescribeCaptchaDataRequest(AbstractModel):
         self.Start = params.get("Start")
         self.End = params.get("End")
         self.Type = params.get("Type")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeCaptchaDataResponse(AbstractModel):
@@ -443,6 +515,13 @@ class DescribeCaptchaDataSumRequest(AbstractModel):
         self.CaptchaAppId = params.get("CaptchaAppId")
         self.Start = params.get("Start")
         self.End = params.get("End")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeCaptchaDataSumResponse(AbstractModel):
@@ -500,11 +579,11 @@ class DescribeCaptchaMiniDataRequest(AbstractModel):
         """
         :param CaptchaAppId: 验证码应用ID
         :type CaptchaAppId: int
-        :param Start: 查询开始时间
+        :param Start: 查询开始时间 例如：2019112900
         :type Start: int
-        :param End: 查询结束时间
+        :param End: 查询结束时间 例如：2019112902
         :type End: int
-        :param Type: 查询类型
+        :param Type: 查询类型 安全验证码小程序插件分类查询数据接口，请求量type=0、通过量type=1、验证量type=2、拦截量type=3 小时级查询（五小时左右延迟）
         :type Type: int
         """
         self.CaptchaAppId = None
@@ -518,6 +597,13 @@ class DescribeCaptchaMiniDataRequest(AbstractModel):
         self.Start = params.get("Start")
         self.End = params.get("End")
         self.Type = params.get("Type")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeCaptchaMiniDataResponse(AbstractModel):
@@ -579,6 +665,13 @@ class DescribeCaptchaMiniDataSumRequest(AbstractModel):
         self.CaptchaAppId = params.get("CaptchaAppId")
         self.Start = params.get("Start")
         self.End = params.get("End")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeCaptchaMiniDataSumResponse(AbstractModel):
@@ -666,6 +759,13 @@ class DescribeCaptchaMiniOperDataRequest(AbstractModel):
         self.CaptchaAppId = params.get("CaptchaAppId")
         self.Start = params.get("Start")
         self.Type = params.get("Type")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeCaptchaMiniOperDataResponse(AbstractModel):
@@ -712,7 +812,7 @@ class DescribeCaptchaMiniResultRequest(AbstractModel):
         :type CaptchaType: int
         :param Ticket: 验证码返回给用户的票据
         :type Ticket: str
-        :param UserIp: 用户操作来源的外网 IP
+        :param UserIp: 透传业务侧获取到的验证码使用者的IP
         :type UserIp: str
         :param CaptchaAppId: 验证码应用APPID
         :type CaptchaAppId: int
@@ -748,6 +848,13 @@ class DescribeCaptchaMiniResultRequest(AbstractModel):
         self.SceneId = params.get("SceneId")
         self.MacAddress = params.get("MacAddress")
         self.Imei = params.get("Imei")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeCaptchaMiniResultResponse(AbstractModel):
@@ -839,6 +946,13 @@ class DescribeCaptchaMiniRiskResultRequest(AbstractModel):
         self.Imei = params.get("Imei")
         self.SceneCode = params.get("SceneCode")
         self.WeChatOpenId = params.get("WeChatOpenId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeCaptchaMiniRiskResultResponse(AbstractModel):
@@ -908,6 +1022,13 @@ class DescribeCaptchaOperDataRequest(AbstractModel):
         self.CaptchaAppId = params.get("CaptchaAppId")
         self.Start = params.get("Start")
         self.Type = params.get("Type")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeCaptchaOperDataResponse(AbstractModel):
@@ -954,7 +1075,7 @@ class DescribeCaptchaResultRequest(AbstractModel):
         :type CaptchaType: int
         :param Ticket: 前端回调函数返回的用户验证票据
         :type Ticket: str
-        :param UserIp: 用户操作来源的外网 IP
+        :param UserIp: 透传业务侧获取到的验证码使用者的IP
         :type UserIp: str
         :param Randstr: 前端回调函数返回的随机字符串
         :type Randstr: str
@@ -998,6 +1119,13 @@ class DescribeCaptchaResultRequest(AbstractModel):
         self.MacAddress = params.get("MacAddress")
         self.Imei = params.get("Imei")
         self.NeedGetCaptchaTime = params.get("NeedGetCaptchaTime")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeCaptchaResultResponse(AbstractModel):
@@ -1007,28 +1135,29 @@ class DescribeCaptchaResultResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param CaptchaCode: 1	OK	验证通过
-6	user code len error	验证码长度不匹配
-7	captcha no match	验证码答案不匹配/Randstr参数不匹配
-8	verify timeout	验证码签名超时
-9	Sequnce repeat	验证码签名重放
-10	Sequnce invalid	验证码签名序列
-11	Cookie invalid	验证码cookie信息不合法
-12	sig len error	签名长度错误
-13	verify ip no match	ip不匹配
-15	decrypt fail	验证码签名解密失败
-16	appid no match	验证码强校验appid错误
-17	cmd no much	验证码系统命令不匹配
-18	uin no match	号码不匹配
-19	seq redirect	重定向验证
-20	opt no vcode	操作使用pt免验证码校验错误
-21	diff	差别，验证错误
-22	captcha type not match	验证码类型与拉取时不一致
-23	verify type error	验证类型错误
-24	invalid pkg	非法请求包
-25	bad visitor	策略拦截
-26	system busy	系统内部错误
-100	param err	appsecretkey 参数校验错误
+        :param CaptchaCode: 1 OK 验证通过
+6 user code len error 验证码长度不匹配，请检查请求是否带Randstr参数，Randstr参数大小写是否有误
+7 captcha no match 验证码答案不匹配/Randstr参数不匹配，请重新生成Randstr、Ticket进行校验
+8 verify timeout 验证码签名超时，票据已过期，请重新生成Randstr、Ticket票进行校验
+9 Sequnce repeat 验证码签名重放，票据重复使用，请重新生成Randstr、Ticket进行校验
+10 Sequnce invalid 验证码签名序列
+11 Cookie invalid 验证码cookie信息不合法，非法请求，可能存在不规范接入
+12 sig len error 签名长度错误
+13 verify ip no match ip不匹配，非法请求，可能存在不规范接入
+15 decrypt fail 验证码签名解密失败，票据校验失败，请检查Ticket票据是否与前端返回Ticket一致
+16 appid no match 验证码强校验appid错误，请检查CaptchaAppId是否为控制台基础配置界面系统分配的APPID
+17 cmd no much 验证码系统命令不匹配
+18 uin no match 号码不匹配
+19 seq redirect 重定向验证
+20 opt no vcode 操作使用pt免验证码校验错误
+21 diff 差别，验证错误
+22 captcha type not match 验证码类型与拉取时不一致
+23 verify type error 验证类型错误
+24 invalid pkg 非法请求包
+25 bad visitor 策略拦截
+26 system busy 系统内部错误
+100 param err appsecretkey 参数校验错误，请检查AppSecretKey是否与控制台基础配置界面系统分配的APPID、AppSecretKey相对应
+104 Ticket Reuse 票据重复使用，同个票据验证多次，请重新生成Randstr、Ticket进行校验
         :type CaptchaCode: int
         :param CaptchaMsg: 状态描述及验证错误信息
 注意：此字段可能返回 null，表示取不到有效值。
@@ -1066,7 +1195,7 @@ class DescribeCaptchaTicketDataRequest(AbstractModel):
         """
         :param CaptchaAppId: 验证码应用ID
         :type CaptchaAppId: int
-        :param Start: 查询开始时间
+        :param Start: 查询开始时间 例如：20200909
         :type Start: int
         """
         self.CaptchaAppId = None
@@ -1076,6 +1205,13 @@ class DescribeCaptchaTicketDataRequest(AbstractModel):
     def _deserialize(self, params):
         self.CaptchaAppId = params.get("CaptchaAppId")
         self.Start = params.get("Start")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeCaptchaTicketDataResponse(AbstractModel):
@@ -1225,6 +1361,13 @@ reject：拒绝，高风险恶意
         self.UserIp = params.get("UserIp")
         self.RiskLevel = params.get("RiskLevel")
         self.RiskType = params.get("RiskType")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class TicketAmountUnit(AbstractModel):
@@ -1246,6 +1389,13 @@ class TicketAmountUnit(AbstractModel):
     def _deserialize(self, params):
         self.DateKey = params.get("DateKey")
         self.Amount = params.get("Amount")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class TicketInterceptUnit(AbstractModel):
@@ -1267,6 +1417,13 @@ class TicketInterceptUnit(AbstractModel):
     def _deserialize(self, params):
         self.DateKey = params.get("DateKey")
         self.Intercept = params.get("Intercept")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class TicketThroughUnit(AbstractModel):
@@ -1288,6 +1445,13 @@ class TicketThroughUnit(AbstractModel):
     def _deserialize(self, params):
         self.DateKey = params.get("DateKey")
         self.Through = params.get("Through")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class UpdateCaptchaAppIdInfoRequest(AbstractModel):
@@ -1353,6 +1517,13 @@ class UpdateCaptchaAppIdInfoRequest(AbstractModel):
         self.MailAlarm = params.get("MailAlarm")
         self.TopFullScreen = params.get("TopFullScreen")
         self.TrafficThreshold = params.get("TrafficThreshold")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class UpdateCaptchaAppIdInfoResponse(AbstractModel):
